Your message dated Sun, 18 Oct 2009 22:38:44 +0000
with message-id <[email protected]>
and subject line Bug#550989: fixed in ltsp 5.1.90-2
has caused the Debian Bug report #550989,
regarding ltsp-client-core: getltscfg (lts.conf) should support wildcards
to be marked as done.
This means that you claim that the problem has been dealt with.
If this is not the case it is now your responsibility to reopen the
Bug report if necessary, and/or fix the problem forthwith.
(NB: If you are a system administrator and have no idea what this
message is talking about, this may indicate a serious mail system
misconfiguration somewhere. Please contact [email protected]
immediately.)
--
550989: http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=550989
Debian Bug Tracking System
Contact [email protected] with problems
--- Begin Message ---
Package: ltsp-client-core
Version: 5.1.90-1
Severity: wishlist
Tags: patch
It would be useful if getltscfg would support wildcards, e.g.:
[00:0C:6E:*]
XSERVER = nvidia
This is very useful in order to have specific settings for a subset of
computers. E.g. when buying a large number of computers of the same
model, they will usually have one or two MAC address series which can be
matched. The alternative is to add a separate section for each
computer, which requires a lot of work.
I have attached a patch which implements this, but while it seems to
work I can't guarantee that it's 100% correct.
-- System Information:
Debian Release: squeeze/sid
APT prefers testing
APT policy: (900, 'testing'), (800, 'unstable')
Architecture: i386 (i686)
Kernel: Linux 2.6.26-2-686 (SMP w/1 CPU core)
Locale: LANG=nb_NO.UTF-8, LC_CTYPE=nb_NO.UTF-8 (charmap=UTF-8)
Shell: /bin/sh linked to /bin/bash
--- getltscfg.c.orig 2009-09-18 14:16:49.000000000 +0200
+++ getltscfg.c 2009-10-13 12:24:56.000000000 +0200
@@ -28,6 +28,8 @@
#include <net/if.h>
#include <netinet/in.h>
#include <arpa/inet.h>
+#define _GNU_SOURCE /* need the fnmatch FNM_CASEFOLD flag */
+#include <fnmatch.h>
#include "getltscfg.h"
extern FILE *yyin;
@@ -191,13 +193,17 @@
//
// find_chain_entry(), returns TRUE if it found the entry, and FALSE otherwise
//
-int find_chain_entry(char *name)
+int find_chain_entry(char *name, int glob)
{
int fFound = FALSE;
SECTTYPE *worksect;
cursect = headsect;
+ int matches = FALSE;
while( cursect && !fFound ){
- if(strcasecmp(cursect->name,name) == 0){
+ matches = strcasecmp(cursect->name,name) == 0;
+ if (glob)
+ matches = !matches && fnmatch(cursect->name, name, FNM_CASEFOLD) == 0;
+ if(matches){
CHAINTYPE *chainptr = (CHAINTYPE *)malloc(sizeof(CHAINTYPE));
worksect = cursect;
fFound = TRUE;
@@ -429,8 +435,8 @@
// that we are interested in. Then, walk through the linked list
// looking for any entries that indicate we want to "inherit" entries
// from another section. We'll build a new linked list of those
// sections that we want to inherit from. Then, we'll tack the 'Default'
// section on the end of that. Once we have the inheritance list, we
// need to walk that list backwards, building the list of
// tuples (keyword/value pairs).
// Finally, when we are all done, we should have all of the values that
@@ -447,7 +453,7 @@
i = 0;
fFound = FALSE;
while( aWorkstationId[i] && !fFound ){
- if(find_chain_entry(aWorkstationId[i])){
+ if(find_chain_entry(aWorkstationId[i], FALSE)){
fFound = TRUE;
}
i++;
@@ -458,17 +464,33 @@
curtuple = chain->sect->tuple_list;
while(curtuple){
if(strcasecmp(curtuple->keyword,"LIKE") == 0)
- status = find_chain_entry(curtuple->value);
+ status = find_chain_entry(curtuple->value, FALSE);
curtuple = curtuple->next;
}
chain = chain->next;
}
+ for (i=0; aWorkstationId[i]; ++i){
+ if((status = find_chain_entry(aWorkstationId[i], TRUE))){
+ chain = headchain;
+ while(chain){
+ curtuple = chain->sect->tuple_list;
+ while(curtuple){
+ if(strcasecmp(curtuple->keyword,"LIKE") == 0)
+ status = find_chain_entry(curtuple->value, FALSE);
+
+ curtuple = curtuple->next;
+ }
+ chain = chain->next;
+ }
+ }
+ }
+
//
// the last entry in the chain is the '[Default]' entry
//
- status = find_chain_entry("default");
+ status = find_chain_entry("default", FALSE);
curchain = tailchain;
--- End Message ---
--- Begin Message ---
Source: ltsp
Source-Version: 5.1.90-2
We believe that the bug you reported is fixed in the latest version of
ltsp, which is due to be installed in the Debian FTP archive:
ltsp-client-builder_5.1.90-2_all.udeb
to pool/main/l/ltsp/ltsp-client-builder_5.1.90-2_all.udeb
ltsp-client-core_5.1.90-2_i386.deb
to pool/main/l/ltsp/ltsp-client-core_5.1.90-2_i386.deb
ltsp-client_5.1.90-2_i386.deb
to pool/main/l/ltsp/ltsp-client_5.1.90-2_i386.deb
ltsp-server-standalone_5.1.90-2_all.deb
to pool/main/l/ltsp/ltsp-server-standalone_5.1.90-2_all.deb
ltsp-server_5.1.90-2_all.deb
to pool/main/l/ltsp/ltsp-server_5.1.90-2_all.deb
ltsp_5.1.90-2.diff.gz
to pool/main/l/ltsp/ltsp_5.1.90-2.diff.gz
ltsp_5.1.90-2.dsc
to pool/main/l/ltsp/ltsp_5.1.90-2.dsc
A summary of the changes between this version and the previous one is
attached.
Thank you for reporting the bug, which will now be closed. If you
have further comments please address them to [email protected],
and the maintainer will reopen the bug report if appropriate.
Debian distribution maintenance software
pp.
Vagrant Cascadian <[email protected]> (supplier of updated ltsp package)
(This message was generated automatically at their request; if you
believe that there is a problem with it please contact the archive
administrators by mailing [email protected])
-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA1
Format: 1.8
Date: Sun, 18 Oct 2009 13:44:14 -0700
Source: ltsp
Binary: ltsp-server ltsp-server-standalone ltsp-client-core ltsp-client
ltsp-client-builder
Architecture: source all i386
Version: 5.1.90-2
Distribution: unstable
Urgency: low
Maintainer: LTSP Debian/Ubuntu Maintainers
<[email protected]>
Changed-By: Vagrant Cascadian <[email protected]>
Description:
ltsp-client - complete LTSP client environment
ltsp-client-builder - build an LTSP environment in the installer target (udeb)
ltsp-client-core - basic LTSP client environment
ltsp-server - basic LTSP server environment
ltsp-server-standalone - complete LTSP server environment
Closes: 550989
Changes:
ltsp (5.1.90-2) unstable; urgency=low
.
* ltsp-client-core:
- Support wildcards in lts.conf. Thanks to John S. Skogtvedt for the patch
to getltscfg (Closes: #550989).
- Patch adding LSB headers to start after hal to ltsp-client-core init
script.
- Add /etc/cups and /etc/cron.d directories to the package, to ensure that
printing and timed shutdown features will work.
- Add suggests on cups-bsd.
.
* ltsp-client:
- add depends on cups-bsd
.
* Changes to support GNU/kFreeBSD:
- ltsp-server:
+ Add patch to use ifconfig from freebsd-net-tools as an alternative to
the ip command from iproute and adjust dependencies accordingly.
+ Add patch to select appropriate kfreebsd-image kernel.
.
- ltsp-client-core:
+ Add patch to ltsp-client-core init script that provides an alternative
method to mount a writeable filesystem.
+ Add patch to getltscfg to remove support for mac address matching on
kfreebsd.
+ Exclude dependencies on nbd-client, kbd, console-tools and
initramfs-tools on kfreebsd-i386 and kfreebsd-amd64 architectures.
Checksums-Sha1:
58f064b1999d54c1788ad62702baab8e7c93c74d 1546 ltsp_5.1.90-2.dsc
7414e9661f686c5ce39b06c0550d40e033662eb7 71665 ltsp_5.1.90-2.diff.gz
ccd6b3b8d42a10c507dca2e22df67d20dc793a21 125302 ltsp-server_5.1.90-2_all.deb
c9cee9599d9443f0d827ad30f90b811265df2621 47008
ltsp-server-standalone_5.1.90-2_all.deb
bcf76dbfb800c75559e8b3dfb23dec09d57039a5 8562
ltsp-client-builder_5.1.90-2_all.udeb
60bc3092faa9ade7eeb4522cd4a8ea0dafe1fae6 106900
ltsp-client-core_5.1.90-2_i386.deb
d66d6fc64d6a550afcc5bbf90d52ce128f4eadac 46378 ltsp-client_5.1.90-2_i386.deb
Checksums-Sha256:
405337e3e005d19ac73d0fe2c9331d68f59c8aa864ff8636804595049be45578 1546
ltsp_5.1.90-2.dsc
8b10cbf76c8bc3871efdfadcb231d69b5bb99646abcc705a1f0b1d55bf94cf09 71665
ltsp_5.1.90-2.diff.gz
8f7cfb3b942445ca1de2618e827523af0f069a931fb878b1fe6ef1f3ecc3e5c4 125302
ltsp-server_5.1.90-2_all.deb
530f21f2472f6431027baab45abed97fd8336753b2567e5c7546fad601088599 47008
ltsp-server-standalone_5.1.90-2_all.deb
c7a91d37a8372fa6111c29585dea40086306a6abbe00b2ed358a64392f49c008 8562
ltsp-client-builder_5.1.90-2_all.udeb
402c584cd02fb5b77a6720f62815da84491ed27afc97c0bbd9c7b33e4d9bbff7 106900
ltsp-client-core_5.1.90-2_i386.deb
bf756837247d7bc0d7f242693400b839985353dad66ff3a5831afecc1d51e10c 46378
ltsp-client_5.1.90-2_i386.deb
Files:
4275670c35cc12ec10e5d036e2ba7860 1546 misc extra ltsp_5.1.90-2.dsc
cc7801e48571b4113b2cbb7cc58511df 71665 misc extra ltsp_5.1.90-2.diff.gz
e6a1d38de59872eb8ae91fe534a2eedd 125302 misc extra ltsp-server_5.1.90-2_all.deb
e9b1267fd19e89c4906b9ce8fadaa39c 47008 misc extra
ltsp-server-standalone_5.1.90-2_all.deb
d9210ca287d6c3d30ade7f52f46b47cf 8562 debian-installer extra
ltsp-client-builder_5.1.90-2_all.udeb
101d30236a43204e7448958203425a55 106900 misc extra
ltsp-client-core_5.1.90-2_i386.deb
20cdd72f64243efceaaa1304c49a6d32 46378 misc extra ltsp-client_5.1.90-2_i386.deb
Package-Type: udeb
-----BEGIN PGP SIGNATURE-----
Version: GnuPG v1.4.9 (GNU/Linux)
iEYEARECAAYFAkrbgMoACgkQlPc63BPWGpnoqQCgnpLFi5GOf7SKI5db8oIYSF0U
QjAAoJyBnWaeuddGxD245QrZwWZGjzJE
=zACW
-----END PGP SIGNATURE-----
--- End Message ---
@@ -429,8 +435,8 @@
// looking for any entries that indicate we want to "inherit" entries
// from another section. We'll build a new linked list of those
- // sections that we want to inherit from. Then, we'll tack the 'Default'
- // section on the end of that. Once we have the inheritance list, we
+ // sections that we want to inherit from. Then, we'll tack any wildcard matches
+ // and the 'Default' section on the end of that. Once we have the inheritance list, we
// need to walk that list backwards, building the list of
// tuples (keyword/value pairs).